@@ -15,6 +15,7 @@ from pyinspirehep.data_models import (
     SingleRecordResponse,
 )
 from pyinspirehep.author import Author
+from pyinspirehep.literature import Literature
 
 
 class Client:
@@ -364,6 +365,35 @@ class Client:
             identifier_value=literature_id,
             )
 
+    def get_literature_citations(
+        self,
+        literature_id: str,
+        size=1000,
+        page=1,
+        ):
+        """
+
+        Parameters
+        ----------
+        literature_id : str
+            The id of literature that its citations are wanted
+
+        Returns
+        -------
+        dict
+
+        >>> client = Client()
+        >>> paper = client.get_literature("1785369")
+        >>> len(client.get_literature_citations("1785369")["hits"]["hits"][1]["metadata"]["references"])
+        133
+        """
+        args=[
+            self.REST_API_URL + 'literature',
+            f"?q=refersto%3Arecid%3A{literature_id}" + f'&size={size}' + f'&page={page}',
+            ]
+        print(Client._create_uri(*args))
+        return self._get(Client._create_uri(*args))
+
     def get_literature_object(
         self,
         literature_id: str,
@@ -383,11 +413,9 @@ class Client:
         SingleRecordResponse
 
         """
-        return self._get_record_object(
-            *args,
-            identifier_type='literature',
-            identifier_value=literature_id,
-            )
+        return Literature.from_response(
+            self.get_literature(literature_id, *args),
+        )
 
     def search_literature(
         self,
